@@ -3,13 +3,12 @@
 mod history;
 mod linear_map;
 mod linear_set;
-pub mod spsc;
+pub mod sync;
 mod vec;
 mod vec_deque;
 
 pub use history::History;
 pub use linear_map::LinearMap;
 pub use linear_set::LinearSet;
-pub use spsc::Spsc;
 pub use vec::Vec;
 pub use vec_deque::VecDeque;
